@@ -8,34 +8,40 @@ typedef struct _gaainfo gaainfo;
 
 struct _gaainfo
 {
-#line 89 "serv.gaa"
+#line 98 "serv.gaa"
 	char **ctype;
-#line 88 "serv.gaa"
+#line 97 "serv.gaa"
 	int nctype;
-#line 85 "serv.gaa"
+#line 94 "serv.gaa"
 	char **kx;
-#line 84 "serv.gaa"
+#line 93 "serv.gaa"
 	int nkx;
-#line 81 "serv.gaa"
+#line 90 "serv.gaa"
 	char **macs;
-#line 80 "serv.gaa"
+#line 89 "serv.gaa"
 	int nmacs;
-#line 77 "serv.gaa"
+#line 86 "serv.gaa"
 	char **comp;
-#line 76 "serv.gaa"
+#line 85 "serv.gaa"
 	int ncomp;
-#line 73 "serv.gaa"
+#line 82 "serv.gaa"
 	char **proto;
-#line 72 "serv.gaa"
+#line 81 "serv.gaa"
 	int nproto;
-#line 69 "serv.gaa"
+#line 78 "serv.gaa"
 	char **ciphers;
-#line 68 "serv.gaa"
+#line 77 "serv.gaa"
 	int nciphers;
-#line 64 "serv.gaa"
+#line 73 "serv.gaa"
 	char *srp_passwd_conf;
-#line 61 "serv.gaa"
+#line 70 "serv.gaa"
 	char *srp_passwd;
+#line 67 "serv.gaa"
+	int require_cert;
+#line 64 "serv.gaa"
+	char *x509_dsacertfile;
+#line 61 "serv.gaa"
+	char *x509_dsakeyfile;
 #line 58 "serv.gaa"
 	char *x509_certfile;
 #line 55 "serv.gaa"
@@ -81,7 +87,7 @@ extern "C"
 
     void gaa_help(void);
     
-    int gaa_file(char *name, gaainfo *gaaval);
+    int gaa_file(const char *name, gaainfo *gaaval);
     
 #ifdef __cplusplus
 }
