@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 /* This server is heavily modified for GNUTLS by Nikos Mavroyanopoulos
@@ -50,6 +50,7 @@ static int debug;
 
 int verbose;
 static int nodb;
+int require_cert;
 
 char *srp_passwd;
 char *srp_passwd_conf;
@@ -117,8 +118,7 @@ static int wrap_db_delete(void *dbf, gnutls_datum key);
 #define HTTP_STATE_CLOSING	3
 
 LIST_TYPE_DECLARE(listener_item, char *http_request; char *http_response;
-		  int request_length;
-		  int response_length;
+		  int request_length; int response_length;
 		  int response_written; int http_state; int fd;
 		  gnutls_session tls_session;
 		  int handshake_ok;
@@ -166,7 +166,7 @@ static int generate_dh_primes(void)
 
     /* Generate Diffie Hellman parameters - for use with DHE
      * kx algorithms. These should be discarded and regenerated
-     * once a day, once a week or once a month. Depends on the
+     * once a week or once a month. Depends on the
      * security requirements.
      */
     printf
@@ -280,7 +280,7 @@ int cipher_priority[PRI_MAX] =
 int comp_priority[PRI_MAX] =
     { GNUTLS_COMP_ZLIB, GNUTLS_COMP_LZO, GNUTLS_COMP_NULL, 0 };
 int mac_priority[PRI_MAX] =
-    { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, GNUTLS_MAC_RMD160, 0 };
+    { GNUTLS_MAC_SHA1, GNUTLS_MAC_MD5, GNUTLS_MAC_RMD160, 0 };
 int cert_type_priority[PRI_MAX] =
     { GNUTLS_CRT_X509, GNUTLS_CRT_OPENPGP, 0 };
 
@@ -319,7 +319,10 @@ gnutls_session initialize_session(void)
     if (cert_cred != NULL)
 	gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, cert_cred);
 
-    gnutls_certificate_server_set_request(session, GNUTLS_CERT_REQUEST);
+    if (require_cert)
+	    gnutls_certificate_server_set_request(session, GNUTLS_CERT_REQUIRE);
+    else
+	    gnutls_certificate_server_set_request(session, GNUTLS_CERT_REQUEST);
 
     return session;
 }
@@ -837,6 +840,7 @@ int main(int argc, char **argv)
 			check_alert(j->tls_session, r);
 			/* nothing */
 		    } else if (r < 0 && gnutls_error_is_fatal(r) == 1) {
+			check_alert(j->tls_session, r);
 			fprintf(stderr, "Error in handshake\n");
 			GERR(r);
 
@@ -921,6 +925,7 @@ int main(int argc, char **argv)
 			int ret;
 
 			j->http_state = HTTP_STATE_CLOSING;
+			check_alert(j->tls_session, r);
 			fprintf(stderr, "Error in handshake\n");
 			GERR(r);
 
@@ -1030,6 +1035,7 @@ void gaa_parser(int argc, char **argv)
 	exit(1);
     }
 
+    require_cert = info.require_cert;
     debug = info.debug;
     verbose = info.quiet;
     nodb = info.nodb;
@@ -1085,7 +1091,7 @@ void serv_version(void)
 /* session resuming support */
 
 #define SESSION_ID_SIZE 32
-#define SESSION_DATA_SIZE 3*1024
+#define SESSION_DATA_SIZE 1024
 
 typedef struct {
     char session_id[SESSION_ID_SIZE];
